@@ -26,11 +26,11 @@ import scipy.constants as codata
 from silx.gui.plot import Plot2D
 
 from orangecontrib.xoppy.widgets.gui.messages import  showCriticalMessage
-from orangecontrib.xoppy.util.srcalc.srcalc import  load_srcalc_output_file, ray_tracing
-from orangecontrib.xoppy.util.srcalc.srcalc import  compute_power_density_footprint, compute_power_density_image
-from orangecontrib.xoppy.util.srcalc.srcalc import  trapezoidal_rule_2d, trapezoidal_rule_2d_1darrays
-from orangecontrib.xoppy.util.srcalc.srcalc import  write_ansys_files
-from orangecontrib.xoppy.util.xoppy_util import locations
+from xoppylib.srcalc.srcalc import  load_srcalc_output_file, ray_tracing
+from xoppylib.srcalc.srcalc import  compute_power_density_footprint, compute_power_density_image
+from xoppylib.srcalc.srcalc import  trapezoidal_rule_2d, trapezoidal_rule_2d_1darrays
+from xoppylib.srcalc.srcalc import  write_ansys_files
+from xoppylib.xoppy_util import locations
 from orangecontrib.xoppy.widgets.gui.image_view_with_fwhm import ImageViewWithFWHM
 
 #
@@ -1744,7 +1744,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
 
         import os
         from orangecontrib.xoppy.widgets.gui.text_window import TextWindow
-        # from orangecontrib.xoppy.util.xoppy_util import locations
+        # from xoppylib.xoppy_util import locations
 
         home_doc = locations.home_doc()
 
