@@ -7,7 +7,7 @@ from oasys.widgets import gui as oasysgui, congruence
 from orangewidget.settings import Setting
 
 from orangecontrib.xoppy.widgets.gui.ow_xoppy_widget import XoppyWidget
-from orangecontrib.xoppy.util.xoppy_bm_wiggler import xoppy_calc_bm
+from xoppylib.sources.xoppy_bm_wiggler import xoppy_calc_bm
 
 from oasys.widgets.exchange import DataExchangeObject
 
@@ -346,9 +346,10 @@ class OWbm(XoppyWidget, WidgetDecorator):
             "FILE_DUMP"       : self.FILE_DUMP,
             }
 
-        self.xoppy_script.set_code(self.script_template().format_map(dict_parameters))
+        script = self.script_template().format_map(dict_parameters)
+        self.xoppy_script.set_code(script)
 
-        return a6_T, fm, a, energy_ev
+        return a6_T, fm, a, energy_ev, script
 
 
 
@@ -357,16 +358,19 @@ class OWbm(XoppyWidget, WidgetDecorator):
 #
 # script to make the calculations (created by XOPPY:bm)
 #
-from orangecontrib.xoppy.util.xoppy_bm_wiggler import xoppy_calc_bm
+from xoppylib.sources.xoppy_bm_wiggler import xoppy_calc_bm
 
+# for full description of inputs and outputs see https://github.com/oasys-kit/xoppylib/blob/main/xoppylib/sources/xoppy_bm_wiggler.py
 # TYPE_CALC: 
 # 0: 'Energy or Power spectra'
 # 1: 'Angular distribution (all wavelengths)'
 # 2: 'Angular distribution (one wavelength)'
 # 3: '2D flux and power (angular,energy) distribution'
 #
-a6_T, fm, a, energy_ev =  xoppy_calc_bm(
-    TYPE_CALC={TYPE_CALC},
+TYPE_CALC={TYPE_CALC}
+VER_DIV={VER_DIV}
+a6_T, fm, a, energy =  xoppy_calc_bm(
+    TYPE_CALC=TYPE_CALC,
     MACHINE_NAME="{MACHINE_NAME}",
     RB_CHOICE={RB_CHOICE},
     MACHINE_R_M={MACHINE_R_M},
@@ -374,7 +378,7 @@ a6_T, fm, a, energy_ev =  xoppy_calc_bm(
     BEAM_ENERGY_GEV={BEAM_ENERGY_GEV},
     CURRENT_A={CURRENT_A},
     HOR_DIV_MRAD={HOR_DIV_MRAD},
-    VER_DIV={VER_DIV},
+    VER_DIV=VER_DIV,
     PHOT_ENERGY_MIN={PHOT_ENERGY_MIN},
     PHOT_ENERGY_MAX={PHOT_ENERGY_MAX},
     NPOINTS={NPOINTS},
@@ -384,6 +388,29 @@ a6_T, fm, a, energy_ev =  xoppy_calc_bm(
     PSI_MAX={PSI_MAX},
     PSI_NPOINTS={PSI_NPOINTS},
     FILE_DUMP=True) # writes output to bm.spec
+
+# data to pass to power
+if TYPE_CALC == 0 and VER_DIV in [0,2]:
+    flux = a6_T[:,5]
+    spectral_power = a6_T[:,6]
+    cumulated_power = a6_T[:,7]
+#   
+# example plot
+#
+if TYPE_CALC == 0 and VER_DIV in [0,2]:
+    from srxraylib.plot.gol import plot
+
+    plot(energy,flux,
+        xtitle="Photon energy [eV]",ytitle="Flux [photons/s/o.1%bw]",title="BM Flux",
+        xlog=True,ylog=True,show=False)
+    plot(energy,spectral_power,
+        xtitle="Photon energy [eV]",ytitle="Power [W/eV]",title="BM Spectral Power",
+        xlog=True,ylog=True,show=False)
+    plot(energy,cumulated_power,
+      xtitle="Photon energy [eV]",ytitle="Cumulated Power [W]",title="BM Cumulated Power",
+      xlog=False,ylog=False,show=True)
+    
+    
 #
 # end script
 #
@@ -397,17 +424,18 @@ a6_T, fm, a, energy_ev =  xoppy_calc_bm(
         return "BM"
 
     def extract_data_from_xoppy_output(self, calculation_output):
-        data, fm, a, energy_ev = calculation_output
+        data, fm, a, energy_ev, script = calculation_output
         
         calculated_data = DataExchangeObject("XOPPY", self.get_data_exchange_widget_name())
         calculated_data.add_content("xoppy_data",  data)
         calculated_data.add_content("xoppy_data_3D",  [fm, a, energy_ev])
+        calculated_data.add_content("xoppy_script", script)
 
         return calculated_data
 
     def getTitles(self):
         if self.TYPE_CALC == 0:
-            return ['E/Ec', 'Flux s-pol/Flux total', 'Flux p-pol/Flux total', 'Flux', 'Spectral Power']
+            return ['E/Ec', 'Flux s-pol/Flux total', 'Flux p-pol/Flux total', 'Flux', 'Spectral Power', 'Cumulated Power']
         elif self.TYPE_CALC == 1:
             return ["Psi[rad]*Gamma", "F", "F s-pol", "F p-pol", "Spectral Power"]
         elif self.TYPE_CALC == 2:
@@ -417,7 +445,7 @@ a6_T, fm, a, energy_ev =  xoppy_calc_bm(
 
     def getXTitles(self):
         if self.TYPE_CALC == 0:
-            return ["Energy [eV]", "Energy [eV]", "Energy [eV]", "Energy [eV]", "Energy [eV]"]
+            return ["Energy [eV]", "Energy [eV]", "Energy [eV]", "Energy [eV]", "Energy [eV]", "Energy [eV]"]
         elif self.TYPE_CALC == 1:
             return ["Psi [mrad]", "Psi [mrad]", "Psi [mrad]", "Psi [mrad]", "Psi [mrad]"]
         elif self.TYPE_CALC == 2:
@@ -428,23 +456,23 @@ a6_T, fm, a, energy_ev =  xoppy_calc_bm(
     def getYTitles(self):
         if self.TYPE_CALC == 0:
             if self.VER_DIV == 0:
-                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/sec/0.1%bw]', 'Power [Watts/eV]']
+                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/s/0.1%bw]', 'Spectral Power [W/eV]', 'Cumulated Power [W]']
             elif self.VER_DIV == 1:
-                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/sec/0.1%bw/mrad(Psi)]', 'Power[Watts/eV/mrad(Psi)]']
+                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/s/0.1%bw/mrad(Psi)]', 'Spectral Power[W/eV/mrad(Psi)]', 'Cumulated Power [W]/mrad(Psi)']
             elif self.VER_DIV == 2:
-                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/sec/0.1%bw]', 'Power [Watts/eV]']
+                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/s/0.1%bw]', 'Spectral Power [W/eV]', 'Cumulated Power [W]']
             elif self.VER_DIV == 3:
-                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/sec/0.1%bw/mrad(Psi)]', 'Power [Watts/eV/mrad(Psi)]']
+                return ['E/Ec', 'Flux_spol/Flux_total', 'Flux_ppol/Flux_total', 'Flux [Phot/s/0.1%bw/mrad(Psi)]', 'Spectral Power [W/eV/mrad(Psi)]', 'Cumulated Power [W/mrad(Psi)]']
         elif self.TYPE_CALC == 1:
-           return ["Psi[rad]*Gamma", "F", "F s-pol", "F p-pol", "Power [Watts/mrad(Psi)]"]
+           return ["Psi[rad]*Gamma", "F", "F s-pol", "F p-pol", "Spectral Power [W/mrad(Psi)]"]
         elif self.TYPE_CALC == 2:
-           return ["Psi[rad]*Gamma", "F", "F s-pol", "F p-pol", "Flux [Phot/sec/0.1%bw/mrad(Psi)]", "Power [Watts/mrad(Psi)]"]
+           return ["Psi[rad]*Gamma", "F", "F s-pol", "F p-pol", "Flux [Phot/sec/0.1%bw/mrad(Psi)]", "Spectral Power [W/mrad(Psi)]"]
         elif self.TYPE_CALC == 3:
            return []
 
     def getVariablesToPlot(self):
         if self.TYPE_CALC == 0:
-            return [(0, 2), (0, 3), (0, 4), (0, 5), (0, 6)]
+            return [(0, 2), (0, 3), (0, 4), (0, 5), (0, 6), (0, 7)]
         elif self.TYPE_CALC == 1:
             return [(0, 1), (0, 2), (0, 3), (0, 4), (0, 5)]
         elif self.TYPE_CALC == 2:
@@ -454,7 +482,7 @@ a6_T, fm, a, energy_ev =  xoppy_calc_bm(
 
     def getLogPlot(self):
         if self.TYPE_CALC == 0:
-            return [(True, False), (True, False), (True, False), (True, True), (True, True)]
+            return [(True, False), (True, False), (True, False), (True, True), (True, True), (False, False)]
         elif self.TYPE_CALC == 1:
             return [(False, False), (False, False), (False, False), (False, False), (False, False)]
         elif self.TYPE_CALC == 2:
